# -------------------------------------------------------------------------------------
# MKDoc::Lang::GM
# -------------------------------------------------------------------------------------
#
#       Author : Jean-Michel Hiver (jhiver@mkdoc.com).
#    Copyright : (c) MKDoc Holdings Ltd, 2001
# 
#      Unauthorized modification, use, reuse, distribution or redistribution
#      of this module is stricly forbidden
#
#    Description:
#
#      Language module for Gurmukhi
#
# -------------------------------------------------------------------------------------
package MKDoc::Lang::GM;
use Unicode::String qw /utf8/;
use Unicode::Transliterate;
use MKDoc::Lang::Generic;
use MKDoc::Unicode;
use strict;
use 5.6.0;
use utf8;

our @ISA = qw /MKDoc::Lang::Generic/;


##
# $self->to_latin ($string);
# --------------------------
#   Returns $string stripped down to latin1 charset
#
#   @param - $string : a utf8 string
#   @returns - A iso latin1 string
##
sub to_latin
{
    my $self   = shift;
    my $string = u_shift (\@_);
    
    my $gurmukhi_latin = new Unicode::Transliterate ( from => 'Gurmukhi', to => 'Latin' );
    my $any_nfd        = new Unicode::Transliterate ( from => 'Any',      to => 'NFD'   );
    my $any_nfc        = new Unicode::Transliterate ( from => 'Any',      to => 'NFC'   );
    
    my $transliterated = $gurmukhi_latin->process ($string);
    $transliterated    = $any_nfc->process ($transliterated);
    
    u_mark (\$transliterated);
    $transliterated =~ s/[\xC0-\xC5]/A/g;
    $transliterated =~ s/\xC6/AE/g;
    $transliterated =~ s/\xC7/C/g;
    $transliterated =~ s/[\xC8-\xCB]/E/g;
    $transliterated =~ s/[\xCC-\xCF]/I/g;
    $transliterated =~ s/\xD0/D/g;
    $transliterated =~ s/\xD1/N/g;
    $transliterated =~ s/[\xD2-\xD6]/O/g;
    $transliterated =~ s/\xD8/O/g;
    $transliterated =~ s/[\xD9-\xDC]/U/g;
    $transliterated =~ s/\xDD/Y/g;
    $transliterated =~ s/[\xE0-\xE5]/a/g;
    $transliterated =~ s/\xE6/ae/g;
    $transliterated =~ s/\xE7/c/g;
    $transliterated =~ s/[\xE8-\xEB]/e/g;
    $transliterated =~ s/[\xEC-\xEF]/i/g;
    $transliterated =~ s/\xF0/d/g;
    $transliterated =~ s/\xF1/n/g;
    $transliterated =~ s/[\xF2-\xF6]/o/g;
    $transliterated =~ s/\xF8/o/g;
    $transliterated =~ s/[\xF9-\xFC]/u/g;
    $transliterated =~ s/\xFD/y/g;
    $transliterated =~ s/FF/y/g;
    
    $transliterated = $any_nfd->process ($transliterated);
    
    u_mark (\$transliterated);
    $transliterated =~ s/[^\x00-\xFF]//g;
    
    my $u_str = utf8 ($transliterated);
    return $u_str->latin1;
}


1;
