# -------------------------------------------------------------------------------------
# MKDoc::Lang::Latin1
# -------------------------------------------------------------------------------------
#
#       Author : Jean-Michel Hiver (jhiver@mkdoc.com).
#    Copyright : (c) MKDoc Holdings Ltd, 2001
# 
#      Unauthorized modification, use, reuse, distribution or redistribution
#      of this module is stricly forbidden
#
#    Description:
#
#      From http://czyborra.com/charsets/iso8859.html#ISO-8859-1
#
#      <cite>
#        Latin1 covers most West European languages, such as French (fr),
#        Spanish (es), Catalan (ca), Basque (eu), Portuguese (pt), Italian (it),
#        Albanian (sq), Rhaeto-Romanic (rm), Dutch (nl), German (de), Danish (da),
#        Swedish (sv), Norwegian (no), Finnish (fi), Faroese (fo), Icelandic (is),
#        Irish (ga), Scottish (gd), and English (en), incidentally also Afrikaans (af)
#        and Swahili (sw)
#      </cite>
#
# -------------------------------------------------------------------------------------
package MKDoc::Lang::Latin1;
use Unicode::String qw /utf8/;
use MKDoc::Lang::Generic;
use MKDoc::Unicode;
use strict;
use 5.6.0;
use utf8;

our @ISA = qw /MKDoc::Lang::Generic/;


##
# $self->to_latin ($string);
# --------------------------
#   Returns $string stripped down to latin1 charset
#
#   @param - $string : a utf8 string
#   @returns - A iso latin1 string
##
sub to_latin
{
    my $self   = shift;
    my $string = u_shift (\@_);
    $string =~ s/[^\x00-\xFF]//g;
    my $u_string = utf8 ($string);
    return $u_string->latin1;
}


1;



