# -------------------------------------------------------------------------------------
# MKDoc::Unicode
# -------------------------------------------------------------------------------------
#
#       Author : Jean-Michel Hiver (jhiver@mkdoc.com).
#    Copyright : (c) MKDoc Holdings Ltd, 2001
# 
#      Unauthorized modification, use, reuse, distribution or redistribution
#      of this module is stricly forbidden
#
#    Description:
#
#      A class to handle most annoying unicode stuff
#
# -------------------------------------------------------------------------------------
package MKDoc::Unicode;
use Exporter;
use UTF8::Hack;
use Unicode::String;
use strict;
use 5.6.0;

our @ISA = qw /Exporter/;
our @EXPORT = qw /u_readfile u_shift u_mark u_convert_arrayref/;


##
# u_convert_arrayref ($arrayref);
# -------------------------------
#   Turns all the strings in $arrayref into utf8
#   if needed
##
sub u_convert_arrayref
{
    my $arrayref = shift;
    for (my $i=0; $i < @{$arrayref}; $i++)
    {
	if (defined $arrayref->[$i] and (not ref $arrayref->[$i]))
	{
	    unless (UTF8::Hack::isutf8 ($arrayref->[$i]))
	    {
		my $u_string = Unicode::String::latin1 ($arrayref->[$i]);
		$arrayref->[$i] = $u_string->utf8;
		+ UTF8::Hack::utf8on ($arrayref->[$i]);
	    }
	}
    }
}


##
# u_readfile ($file);
# ------------------
#   Returns the contents of $file marked as utf8,
#   dies if the file could not be opened.
#
#   @param - $file : A file path to read
#   @returns - The contents of $file marked as utf8
##
sub u_readfile ($)
{
    my $file = shift;
    open FP, "<$file" or die "Cannot read-open $file: $!";
    my $data = join '', <FP>;
  UTF8::Hack::utf8on ($data);
    return $data;
}


##
# u_shift ($);
# ------------
#   (Almost) same as shift, but the result is always converted
#   to utf8
#
#   @param - An array reference of values
#   @returns - the utf8 marked shifted value of the array
##
sub u_shift ($)
{
    my $arry_ref = shift;
    my $string = shift (@{$arry_ref});
    return undef unless (defined $string);
  UTF8::Hack::utf8on ($string) if (UTF8::Hack::isutf8 ($string));
    return $string;
}


##
# u_mark ($scalarref);
# --------------------
#   Marks the scalar value pointed by scalarref as utf8
#
#   @param - An array reference of a scalar
#   @returns - nothing
##
sub u_mark ($)
{
    my $ref = shift;
    return unless (defined $$ref);
  UTF8::Hack::utf8on ($$ref) unless (UTF8::Hack::isutf8 ($$ref));
}


1;


