# -------------------------------------------------------------------------------------
# lib::sql::Query
# -------------------------------------------------------------------------------------
#
#       Author : Jean-Michel Hiver (jhiver@cisedi.com).
#    Copyright : (c) Jean-Michel Hiver, 2000.
# 
#      Unauthorized modification, use, reuse, distribution or redistribution
#      of this module is stricly forbidden.
#
#    Description:
#
#      This class represents queries performed onto the database. It also takes
#      care of marking strings which are pulled out the database as utf8.
#
# -------------------------------------------------------------------------------------
package lib::sql::Query;
use lib::Exception;
use UTF8::Hack;
use Unicode::String;
use strict;
use vars qw /$IMPORTED/;
$IMPORTED = {};


##
# $class->new;
# ------------
#   Constructs a new lib::sql::Query object.
##
sub new
{
    my $class = shift;
    $class = ref $class || $class;
    
    return bless { @_ }, $class;
}


##
# $obj->next;
# -----------
#   Returns next record, and bless it if necessary.
##
sub next
{
    my $self = shift;
    my $hash = $self->{sth}->fetchrow_hashref;
    my $bless_into = $self->{bless_into};
    
    if (defined $bless_into)
    {
	if (not $IMPORTED->{$bless_into})
	{
	    eval "use $bless_into" unless (defined $IMPORTED->{$bless_into});
	    if ($@) {
		throw (new lib::Exception ( code => 'CANNOT_IMPORT',
					    info => $@ ) );
	    }
	    $IMPORTED->{$bless_into} = 1;
	}
	
	bless $hash, $bless_into if (ref $hash and defined $bless_into);
    }
    
    $self->_make_valid_unicode_hash ($hash) if (defined $hash);
    return $hash;
}


##
# $obj->fetch_all;
# ----------------
#   Returns an array of all objects that could be fetched
##
sub fetch_all
{
    my $self = shift;
    my @res  = ();

    my @array = ();    
    my $bless_into = $self->{bless_into};
    if (defined $bless_into)
    {
	eval "use $bless_into" unless (defined $IMPORTED->{$bless_into});
	if ($@) {
	    throw (new lib::Exception ( code => 'CANNOT_IMPORT',
					info => $@ ) );
	}
	
	while (my $hash = $self->{sth}->fetchrow_hashref)
	{
	    $self->_make_valid_unicode_hash ($hash);
	    bless $hash, $bless_into;
	    push @array, $hash;
	}
    }
    else
    {
	while (my $hash = $self->{sth}->fetchrow_hashref)
	{
	    $self->_make_valid_unicode_hash ($hash);
	    push @array, $hash;
	}
    }
    
    return (wantarray) ? @array : \@array;
}


##
# $obj->fetch_all_firstvalue;
# ---------------------------
#   Returns an array of all objects that could be fetched
##
sub fetchall_arrayref
{
    my $self  = shift;
    my @array = @{$self->{sth}->fetchall_arrayref};
    for my $arry_ref (@array)
    {
	for (my $i=0; $i < scalar @{$arry_ref}; $i++)
	{
	    next unless (defined $arry_ref->[$i]);
	    eval {
		my $u_string = Unicode::String::utf8 ($arry_ref->[$i]);
		my $val = $u_string->utf8;
		+ UTF8::Hack::utf8on ($val);
		$arry_ref->[$i] = $val;
	    };
	    if (defined $@ and $@)
	    {
		warn "Invalid Unicode String: $arry_ref->[$i]\n";
		$arry_ref->[$i] = undef;
	    }
	}
    }
    
    return \@array;
}


sub _make_valid_unicode_hash
{
    my $self = shift;
    my $hash = shift;
    
    # make sure the string is valid Unicode,
    # otherwise undef the value + issue a warning
    foreach my $key (keys %{$hash})
    {
	next unless (defined $hash->{$key});
	eval {
	    my $u_string = Unicode::String::utf8 ($hash->{$key});
	    my $val = $u_string->utf8;
	    + UTF8::Hack::utf8on ($val);
	    $hash->{$key} = $val;
	};
	if (defined $@ and $@)
	{
	    warn "Invalid Unicode String: $hash->{$key}\n";
	    $hash->{$key} = undef;
	}
    }
    
    return $hash;
}


1;
