use lib qw /.. site_import/;
use HTML_Page::Factory;
use strict;
use warnings;
use MKDoc;
use DBI;
use flo::Standard;
use URI;


our $USAGE = "$0 <remote_uri> <mkdoc_uri> <extractor> <template>\n" .
             "i.e. $0 http://foo.com http://mkdoc.com/links/ HTML_Page::Links_SQL default";

our $REMOTE_URI = shift || die $USAGE;
our $MKDOC_URI  = shift || die $USAGE;
our $EXTRACTOR  = shift || die $USAGE;
our $TEMPLATE   = shift || die $USAGE;

init();
main();


sub main
{
    my $page = HTML_Page::Factory->mk_html_object ($REMOTE_URI, $EXTRACTOR);
    my $dbh = lib::sql::DBH->spawn->get;
    
    my $uri_object = URI->new();
    die "Cannot process $MKDOC_URI" unless ($MKDOC_URI =~ /\/\/.*\/.*\//);
    my $sth = $dbh->prepare_cached ('DELETE FROM Document WHERE Full_Path LIKE ?');
    my $val = URI->new ($MKDOC_URI)->path . '%';
    $sth->execute($val);
    
    $sth = $dbh->prepare_cached ('DELETE FROM Redirect WHERE Old_Path LIKE ?');
    $sth->execute($val);
    process ($page);
}


sub init
{
    $ENV{PATH_INFO} = '/';
    my $VAR1 = undef;
    open FP, "<../conf/sites.conf" or die "Cannot read-open sites.conf";
    my $data = join '', <FP>;
    close FP;
    $VAR1 = eval "$data" or die "Cannot eval data from sites.conf";
    
    my $uri = new URI ($MKDOC_URI);
    my $host = $uri->host;
    my %websites = %{$VAR1};
    my $base_dir = $websites{$host};
    defined $base_dir || die "$host does not seem to exist";
    $ENV{SERVER_NAME} = $host;
    + MKDoc::init ('cgi.mkdoc');
}


sub process
{
    my $remote_page = shift;
    my $level = shift || 0;
    my $remote_uri = $remote_page->uri;
    my $mkdoc_uri = shift || $MKDOC_URI;
    print "--" x $level . "$remote_uri\n";
    
    my $mkdoc_URI = new URI ($mkdoc_uri);
    my $mkdoc_URI_path = $mkdoc_URI->path();
    $mkdoc_URI_path =~ s/^\///;
    $mkdoc_URI_path =~ s/\/$//;
    
    my $mkdoc_parent_URI_path;
    my $name = undef;
    if ($mkdoc_URI_path)
    {
	my @path = ($mkdoc_URI_path =~ /\//) ? split /\//, $mkdoc_URI_path : ($mkdoc_URI_path);
	@path = map {
	    $_ = lc ($_);
	    s/\W/-/g;
	    s/\_/-/g;
	    s/\-+/-/g;
	    s/^\-//;
	    s/\-$//;
	    $_;
	} @path;
	
	$name = $path[$#path];
	$mkdoc_URI_path = join '/', @path;
	$name = pop (@path);
	$mkdoc_parent_URI_path = join '/', @path;
	$mkdoc_URI_path = "/$mkdoc_URI_path/";
	$mkdoc_parent_URI_path = "/$mkdoc_parent_URI_path/";
	$mkdoc_URI_path =~ s/\/\//\//;
	$mkdoc_parent_URI_path =~ s/\/\//\//;
    }
    
    my $document_t = table ('Document');
    my $parent = $document_t->get ( Full_Path => $mkdoc_parent_URI_path );
    
    my $dbh = lib::sql::DBH->spawn->get;
    my $sth = $dbh->prepare_cached ('INSERT Document VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)');
    
    $sth->execute ( undef,                                       # ID
		    $parent->{ID},                               # Parent_ID
		    10,                                          # Cache_Control
		    $TEMPLATE,                                   # Template
		    $remote_page->description || $name || '',    # Description
		    $remote_page->keywords    || $name || '',    # Keywords
		    $remote_page->date_created_mysql,            # Date_Created
		    $remote_page->date_modified_mysql,           # Date_Last_Modified
		    1,                                           # Editor_Created_ID
		    1,                                           # Editor_Last_Modified_ID
		    $name,                                       # Name
		    $mkdoc_URI_path,                             # Full_Path
		    $remote_page->title || $name || 'no title',  # Title
		    'en',                                        # Lang
		    '',                                          # Rights
		    '',                                          # Publisher
		    '',                                          # Source
		    '',                                          # Relation
		    '',                                          # Coverage
		    $remote_page->body,                          # Body
		    0,                                           # Sibling_Position
		    'Title',                                     # Sort_By
		    0 );                                       # Order_By
    
    $level++;
    for ($remote_page->children)
    {
	$_ = HTML_Page::Factory->mk_html_object ($_, $EXTRACTOR);
	my $new_mkdoc_uri = $mkdoc_uri . '/' . $_->name;
	process ($remote_page->new (uri => $_->uri), $level, $new_mkdoc_uri);
    }
}


1;
