#!/usr/bin/perl
use 5.6.0;
use Carp;
use lib ('..');
use MKDoc;
use flo::Standard;
use lib::Exception;
use strict;

$ENV{SERVER_NAME} || croak "\$ENV{SERVER_NAME} not set";
$ENV{PATH_INFO}   || croak "\$ENV{PATH_INFO} not set";

our $DIR   = undef;
our $SITES = undef;


try
{
    main();
} 
catch
{
    use Data::Dumper;
    die Dumper (@_);
};


sub report
{
    my $label = shift;
    $label = "Checking $label...";
    my $error = shift;
    while (length ($label) < 50) { $label .= ' ' }
    if (defined $error and $error)
    {
	print $label;
	print "[\e[91mFAILED\e[0m]\n";
    }
    else
    {
	print $label;
	print "[\e[92m  OK  \e[0m]\n";
    }
}



sub main
{
    opendir DD, "../t";
    my @files = readdir (DD);
    closedir (DD);
    
    foreach my $file (sort @files)
    {
        $file eq '.' and next;
        $file eq '..' and next;
        $file !~ /\.pl$/ and next;
	
        open FP, "../t/$file";
        my $perl = join '', <FP>;
        close FP;
	
        $file =~ s/\.pl$//;
	my ($number, $name) = $file =~ /(\d+)\.\.(.*)/;
        $number =~ s/^0+//;
        while (length ($number) < 3) { $number = " $number" }
	$name =~ s/-/ /g;
	$name =~ s/\b(\w)/\U$1/g;
        $name = "$number $name";
        eval $perl;
        if (defined $@ and $@) { report ($name, 1) }
        else                   { report ($name)    }
    }
}

=cut

sub build_index
{
    my $document_id = shift;
    my $document_table = table 'Document';
    my $document = $document_table->get ($document_id) or
	warn "document with ID $document_id does not exist\n";
    
    print "Indexing " . $document->Full_Path . "... ";
    $document_table->modify ($document);
    print "OK\n";
    
    my @child = $document_table->search ( Parent_ID => $document_id )->fetch_all;
    for my $doc (@child) { build_index ($doc->{ID}) }
}

=cut

1;
